summaryrefslogtreecommitdiffstats
path: root/kommander/editor/widgetdatabase.h
diff options
context:
space:
mode:
Diffstat (limited to 'kommander/editor/widgetdatabase.h')
-rw-r--r--kommander/editor/widgetdatabase.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kommander/editor/widgetdatabase.h b/kommander/editor/widgetdatabase.h
index 3e4078c5..24b14530 100644
--- a/kommander/editor/widgetdatabase.h
+++ b/kommander/editor/widgetdatabase.h
@@ -1,7 +1,7 @@
/**********************************************************************
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
@@ -25,10 +25,10 @@
#include <tqstring.h>
#ifndef KOMMANDER
#include "widgetinterface.h" // up here for GCC 2.7.* compatibility
-#include <private/qpluginmanager_p.h>
+#include <private/tqpluginmanager_p.h>
-extern QPluginManager<WidgetInterface> *widgetManager();
+extern TQPluginManager<WidgetInterface> *widgetManager();
#endif
struct WidgetDatabaseRecord
@@ -42,7 +42,7 @@ struct WidgetDatabaseRecord
int nameCounter;
};
-class WidgetDatabase : public Qt
+class WidgetDatabase : public TQt
{
public:
WidgetDatabase();
@@ -1,7 +1,7 @@
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the